@@ -15,21 +15,36 @@ sub new {
     die 'no target parameter' unless $params{target};
 
     my $self = {
-        logger      => $params{logger} ||
-                       FusionInventory::Agent::Logger->new(),
-        config      => $params{config},
-        confdir     => $params{confdir},
-        datadir     => $params{datadir},
-        target      => $params{target},
-        prologresp  => $params{prologresp},
-        client      => $params{client},
-        deviceid    => $params{deviceid}
+        logger       => $params{logger} ||
+                        FusionInventory::Agent::Logger->new(),
+        config       => $params{config},
+        confdir      => $params{confdir},
+        datadir      => $params{datadir},
+        target       => $params{target},
+        deviceid     => $params{deviceid},
     };
     bless $self, $class;
 
     return $self;
 }
 
+sub getOptionsFromServer {
+    my ($self, $response, $name, $feature) = @_;
+
+    if (!$response) {
+        $self->{logger}->debug("No server response");
+        return;
+    }
+
+    my $options = $response->getOptionsInfoByName($name);
+    if (!$options) {
+        $self->{logger}->debug("No $feature requested in the prolog");
+        return;
+    }
+
+    return $options;
+}
+
 sub getModules {
     my ($class, $prefix) = @_;
 
@@ -99,6 +114,10 @@ the logger object to use (default: a new stderr logger)
 
 This is the method to be implemented by each subclass.
 
+=head2 getOptionsFromServer($response, $name, $feature)
+
+Get task-specific options in server response to prolog message.
+
 =head2 getModules($prefix)
 
 Return a list of modules for this task. All modules installed at the same
