@@ -14,25 +14,33 @@ use FusionInventory::Agent::XML::Query::Inventory;
 
 our $VERSION = '1.0';
 
-sub run {
-    my ($self) = @_;
+sub isEnabled {
+    my ($self, $response) = @_;
 
-    if ($self->{target}->isa('FusionInventory::Agent::Target::Server')) {
-        die "No server response" unless $self->{prologresp};
+    # always enabled for local target
+    return 1 unless
+        $self->{target}->isa('FusionInventory::Agent::Target::Server');
 
-        if ($self->{config}->{force}) {
-            $self->{logger}->debug(
-                "Force enable, ignore prolog and run inventory."
-            );
-        } else {
-            my $content = $self->{prologresp}->getContent();
-            if (!($content && $content->{RESPONSE} && $content->{RESPONSE} =~ /^SEND$/)) {
-                $self->{logger}->debug("No inventory requested in the prolog");
-                return;
-            }
-        }
+    if ($self->{config}->{force}) {
+        $self->{logger}->debug("Prolog response ignored");
+        return 1;
     }
 
+    my $content = $response->getContent();
+    if (!$content || !$content->{RESPONSE} || $content->{RESPONSE} ne 'SEND') {
+        $self->{logger}->debug("No inventory requested in the prolog response");
+        return;
+    }
+
+    $self->{registry} = $response->getOptionsInfoByName('REGISTRY');
+    return 1;
+}
+
+sub run {
+    my ($self, %params) = @_;
+
+    $self->{logger}->debug("FusionInventory Inventory task $VERSION");
+
     $self->{modules} = {};
 
     my $inventory = FusionInventory::Agent::Task::Inventory::Inventory->new(
@@ -83,13 +91,22 @@ sub run {
             $self->{logger}->error("Can't write to $file: $ERRNO");
         }
     } elsif ($self->{target}->isa('FusionInventory::Agent::Target::Server')) {
+        my $client = FusionInventory::Agent::HTTP::Client::OCS->new(
+            logger       => $self->{logger},
+            user         => $params{user},
+            password     => $params{password},
+            proxy        => $params{proxy},
+            ca_cert_file => $params{ca_cert_file},
+            ca_cert_dir  => $params{ca_cert_dir},
+            no_ssl_check => $params{no_ssl_check},
+        );
 
         my $message = FusionInventory::Agent::XML::Query::Inventory->new(
             deviceid => $self->{deviceid},
             content  => $inventory->getContent()
         );
 
-        my $response = $self->{client}->send(
+        my $response = $client->send(
             url     => $self->{target}->getUrl(),
             message => $message
         );
@@ -139,7 +156,7 @@ sub _initModulesList {
             params => {
                 datadir       => $self->{datadir},
                 logger        => $self->{logger},
-                prologresp    => $self->{prologresp},
+                registry      => $self->{registry},
                 no_software   => $self->{config}->{'no-software'},
                 no_printer    => $self->{config}->{'no-printer'},
                 scan_homedirs => $self->{config}->{'scan-homedirs'},
@@ -210,7 +227,7 @@ sub _runModule {
         $self->_runModule($other_module, $inventory);
     }
 
-    $logger->debug ("Running $module");
+    $logger->debug("Running $module");
 
     runFunction(
         module   => $module,
@@ -220,7 +237,7 @@ sub _runModule {
             datadir       => $self->{datadir},
             inventory     => $inventory,
             logger        => $self->{logger},
-            prologresp    => $self->{prologresp},
+            registry      => $self->{registry},
             no_software   => $self->{config}->{no_software},
             no_printer    => $self->{config}->{no_printer},
             scan_homedirs => $self->{config}->{'scan-homedirs'},
@@ -300,7 +317,9 @@ sub _printInventory {
             my $tpp = XML::TreePP->new(indent => 2);
             print {$params{handle}} $tpp->write({
                 REQUEST => {
-                    CONTENT => $params{inventory}->{content}
+                    CONTENT => $params{inventory}->{content},
+                    DEVICEID => $self->{deviceid},
+                    QUERY => "INVENTORY",
                 }
             });
 
@@ -308,7 +327,7 @@ sub _printInventory {
         }
 
         if ($params{format} eq 'html') {
-
+            Text::Template->require();
             my $template = Text::Template->new(
                 TYPE => 'FILE', SOURCE => "$self->{datadir}/html/inventory.tpl"
             );
