@@ -22,15 +22,16 @@ my %fields = (
     DRIVES      => [ qw/CREATEDATE DESCRIPTION FREE FILESYSTEM LABEL LETTER 
                         SERIAL SYSTEMDRIVE TOTAL TYPE VOLUMN/ ],
     ENVS        => [ qw/KEY VAL/ ],
-    INPUTS      => [ qw/CAPTION DESCRIPTION INTERFACE LAYOUT POINTTYPE TYPE/ ],
+    INPUTS      => [ qw/NAME MANUFACTURER CAPTION DESCRIPTION INTERFACE LAYOUT
+	                POINTINGTYPE TYPE/ ],
     MEMORIES    => [qw/CAPACITY CAPTION FORMFACTOR REMOVABLE PURPOSE SPEED
                        SERIALNUMBER TYPE DESCRIPTION NUMSLOTS/ ],
     MODEMS      => [ qw/DESCRIPTION NAME/ ],
     MONITORS    => [ qw/BASE64 CAPTION DESCRIPTION MANUFACTURER SERIAL
                         UUENCODE/ ],
     NETWORKS    => [ qw/DESCRIPTION DRIVER IPADDRESS IPADDRESS6 IPDHCP IPGATEWAY
-                        IPMASK IPSUBNET MACADDR MTU PCISLOT STATUS TYPE 
-                        VIRTUALDEV SLAVES SPEED MANAGEMENT BSSID SSID/ ],
+                        IPMASK IPSUBNET MACADDR MTU PCISLOT PNPDEVICEID STATUS
+		       	TYPE VIRTUALDEV SLAVES SPEED MANAGEMENT BSSID SSID/ ],
     PORTS       => [ qw/CAPTION DESCRIPTION NAME TYPE/ ],
     PROCESSES   => [ qw/USER PID CPUUSAGE MEM VIRTUALMEMORY TTY STARTED CMD/ ],
     REGISTRY    => [ qw/NAME REGVALUE HIVE/ ],
@@ -38,8 +39,8 @@ my %fields = (
     SOFTWARES   => [ qw/COMMENTS FILESIZE FOLDER FROM HELPLINK INSTALLDATE NAME
                         NO_REMOVE RELEASE_TYPE PUBLISHER UNINSTALL_STRING 
                         URL_INFO_ABOUT VERSION VERSION_MINOR VERSION_MAJOR 
-                        IS64BIT GUID/ ],
-    SOUNDS      => [ qw/DESCRIPTION MANUFACTURER NAME/ ],
+                        IS64BIT GUID RELEASETYPE/ ],
+    SOUNDS      => [ qw/CAPTION DESCRIPTION MANUFACTURER NAME/ ],
     STORAGES    => [ qw/DESCRIPTION DISKSIZE INTERFACE MANUFACTURER MODEL NAME
                         TYPE SERIAL SERIALNUMBER FIRMWARE SCSI_COID SCSI_CHID
                         SCSI_UNID SCSI_LUN WWN/ ],
