@@ -237,10 +237,10 @@ sub getFileHandle {
             last SWITCH;
         }
 	if ($params{string}) {
-	    
 	    open $handle, "<", \$params{string} or die;
+            last SWITCH;
 	}
-        die "neither command nor file parameter given";
+        die "neither command, file or string parameter given";
     }
 
     return $handle;
@@ -346,7 +346,8 @@ sub canLoad {
 sub hex2char {
     my ($value) = @_;
 
-    return unless $value;
+    ## no critic (ExplicitReturnUndef)
+    return undef unless $value;
     return $value unless $value =~ /^0x/;
 
     $value =~ s/^0x//;
@@ -358,7 +359,8 @@ sub hex2char {
 sub hex2dec {
     my ($value) = @_;
 
-    return unless $value;
+    ## no critic (ExplicitReturnUndef)
+    return undef unless $value;
     return $value unless $value =~ /^0x/;
 
     return oct($value);
@@ -367,7 +369,8 @@ sub hex2dec {
 sub dec2hex {
     my ($value) = @_;
 
-    return unless $value;
+    ## no critic (ExplicitReturnUndef)
+    return undef unless $value;
     return $value if $value =~ /^0x/;
 
     return sprintf("0x%x", $value);
@@ -517,16 +520,18 @@ Returns an open file handle on either a command output, or a file.
 
 =head2 getFileHandle(%params)
 
-Returns an open file handle on either a command output, or a file.
+Returns an open file handle on either a command output, a file, or a string.
 
 =over
 
 =item logger a logger object
 
-=item command the exact command to use
+=item command the command to use
 
 =item file the file to use, as an alternative to the command
 
+=item string the string to use, as an alternative to the command
+
 =back
 
 =head2 getFirstLine(%params)
